@@ -6,7 +6,7 @@ from requests.exceptions import HTTPError
 from ..models.adminGroupModel import adminGroup
 
 
-class adminGroups:
+class AdminGroupsService:
     # url snippets
     groups_snippet = "groups"
     users_snippet = "users"
