@@ -28,13 +28,19 @@ def check_flow_already_running_on_another_call(
 
     endpoint = f"{endpoint_task_runs}/filter"
 
-    response = requests.post(endpoint, headers=headers, json=body, timeout=60)
-    if response.status_code != 200:
-        raise Exception(
-            f"Failed to retrieve flows runs of deployment {deployment_id}. Status code: {response.status_code}"
-        )
-
-    flow_runs = response.json()
+    attempts = 0
+    while True:
+        response = requests.post(endpoint, headers=headers, json=body, timeout=60)
+        attempts += 1
+        if response.status_code != 200:
+            if attempts > 5:
+                raise Exception(
+                    f"Failed to retrieve flows runs of deployment {deployment_id}. Status code: {response.status_code}"
+                )
+            
+        if response.status_code == 200:
+            flow_runs = response.json()
+            break
 
     if len(flow_runs) > 1:  # 1 because the flow is running on this call
         if check_parameters is not None:
