@@ -163,6 +163,6 @@ def get_cipher_key(env=PROD):
     try:
         with open(path) as f:
             r = f.read()
-            return r.encode()
+            return r
     except Exception as e:
         return None
